@@ -163,6 +163,22 @@ goc_item_leave_notify (GocItem *item, double x, double y)
 		FALSE;
 }
 
+static gboolean
+goc_item_key_pressed (GocItem *item, GdkEventKey* ev)
+{
+	return (item->parent)?
+		GOC_ITEM_GET_CLASS (item->parent)->key_pressed (GOC_ITEM (item->parent), ev):
+		FALSE;
+}
+
+static gboolean
+goc_item_key_released (GocItem *item, GdkEventKey* ev)
+{
+	return (item->parent)?
+		GOC_ITEM_GET_CLASS (item->parent)->key_released (GOC_ITEM (item->parent), ev):
+		FALSE;
+}
+
 static void
 goc_item_realize (GocItem *item)
 {
@@ -194,7 +210,7 @@ goc_item_dispose (GObject *object)
 			item->canvas->last_item = NULL;
 		if (item->canvas->grabbed_item == item)
 			item->canvas->grabbed_item = NULL;
-		if (gtk_widget_is_realized (item->canvas)) {
+		if (gtk_widget_get_realized (GTK_WIDGET (item->canvas))) {
 			item->cached_bounds = TRUE; /* avoids a call to update_bounds */
 			goc_item_invalidate (item);
 		}
@@ -256,6 +272,8 @@ goc_item_class_init (GocItemClass *item_klass)
 	item_klass->motion = goc_item_motion;
 	item_klass->enter_notify = goc_item_enter_notify;
 	item_klass->leave_notify = goc_item_leave_notify;
+	item_klass->key_pressed = goc_item_key_pressed;
+	item_klass->key_released = goc_item_key_released;
 }
 
 static void
@@ -305,6 +323,7 @@ goc_item_new (GocGroup *parent, GType type, const gchar *first_arg_name, ...)
 	g_return_val_if_fail ((item != NULL), NULL);
 
 	goc_group_add_child (parent, item);
+	goc_item_invalidate (item);
 
 	return item;
 }
@@ -432,7 +451,7 @@ goc_item_invalidate (GocItem *item)
 	if (!parent)
 		return;
 
-	if (!gtk_widget_is_realized (item->canvas))
+	if (!gtk_widget_get_realized (GTK_WIDGET (item->canvas)))
 		return;
 
 	if (!item->cached_bounds)
